translate.tools

Package translate :: Package tools |
[hide private]
[frames] | no frames]

# Package tools

source code

translate.tools is part of the translate package It contains code to perform various operations (mostly on po files)

Submodules | [hide private]
translate.tools.build_tmdb: Import units from translations files into tmdb. translate.tools.phppo2pypo: Convert PHP format .po files to Python format .po files translate.tools.poclean: Produces a clean file from an unclean file (Trados/Wordfast) by stripping out the tw4win indicators. translate.tools.pocompile: Compile XLIFF and Gettext PO localization files into Gettext MO (Machine Object) files translate.tools.poconflicts: Conflict finder for Gettext PO localization files translate.tools.pocount: Create string and word counts for supported localization files including: XLIFF, TMX, Gettex PO and MO, Qt .ts and .qm, Wordfast TM, etc translate.tools.podebug: Insert debug messages into XLIFF and Gettext PO localization files translate.tools.pogrep: Grep XLIFF, Gettext PO and TMX localization files translate.tools.pomerge: Merges XLIFF and Gettext PO localization files translate.tools.porestructure: Restructure Gettxt PO files produced by poconflicts into the original directory tree for merging using pomerge translate.tools.posegment: Segment Gettext PO, XLIFF and TMX localization files at the sentence level. translate.tools.poswap: Builds a new translation file with the target of the input language as source language. translate.tools.poterminology: reads a set of .po or .pot files to produce a pootle-terminology.pot translate.tools.pretranslate: Fill localization files with suggested translations based on translation memory and existing translations. translate.tools.pydiff: diff tool like GNU diff, but lets you have special options that are useful in dealing with PO files translate.tools.pypo2phppo: Convert Python format .po files to PHP format .po files